@@ -10,6 +10,8 @@
 #' @param bsn the number of resampling. Default is bsn = 5000.
 #' 
 #' @param q power of Wasserstein metric. Default is q = 2.
+#'
+#' @param seed seed for random generator.
 #' 
 #' @examples
 #' 
@@ -22,17 +24,24 @@
 #' testRes <- wasser.test(cases = cases,control = control,test.stat = d)
 
 #' @author Yusuke Matsui & Teppei Shimamura
-#' 
+#' @references Yusuke Matsui, Masahiro Mizuta, Satoru Miyano and Teppei Shimamura.(2015) D3M:Detection of differential distributions of methylation patterns (submitted). BIORXIV/2015/023879.
+#' @references Antonio Irpino and Rossanna Verde.(2015) Basic Statistics for distributional symbolic variables: a new metric-based approach. Adv.Data.Anal.Classif(9) 143--175
 #' @return  list of p-value and test statistics.
 #' 
 #' @export
 
-wasser.test <- function(cases, control, test.stat, paranum = 101, bsn = 5000, q = 2){
+wasser.test <- function(cases, control,test.stat, paranum = 101, bsn = 5000, q = 2,seed = 100){
   #library(D3M)
   
   #library(Rcpp)
   
-  res <- permCpp(casesMat = cases, controlMat = control, bsn = bsn, qn = paranum, d = test.stat, q = q)
+  set.seed(seed)
+  
+  nsample <- ncol(cases) + ncol(control)
+  
+  shuffleID <- sapply(1:bsn,function(j)sample(nsample,nsample,replace=FALSE))
+  
+  res <- permCpp(casesMat = cases, controlMat = control, shuffleID = shuffleID, bsn = bsn, qn = paranum, d = test.stat, q = q)
 
   o <- list(pval = res[[1]], tets.stat = test.stat)
   
